@@ -1,5 +1,5 @@
 import abc
-from typing import Any, Callable, Generic, Iterable, NamedTuple, Optional, Sequence, TextIO, TypeVar
+from typing import Any, Callable, Generic, Iterable, Mapping, NamedTuple, Optional, Sequence, TextIO, TypeVar
 from attrs import define
 
 Input = str  # The input to an NLP mode
@@ -43,14 +43,22 @@ class AugmentedSample(metaclass=abc.ABCMeta):
 SampleResults = Iterable[tuple[Performance, tuple[Category, ...]]]
 Results = Iterable[SampleResults]
 
-T = TypeVar("T")
+Aggregate = TypeVar("Aggregate")
 
 
-class StatsAgregator(Generic[T], metaclass=abc.ABCMeta):
+class StatsAggregator(Generic[Aggregate], metaclass=abc.ABCMeta):
     @abc.abstractmethod
-    def __call__(self, performances: Results) -> T:
+    def __call__(self, performances: Results) -> Aggregate:
         ...
 
     @abc.abstractmethod
-    def save_agregation(self, performances: Results, file: Optional[TextIO] = None):
+    def save_aggregation(self, aggregate: Aggregate, file: Optional[TextIO] = None):
+        ...
+
+    @abc.abstractmethod
+    def load_aggregation(self, file: TextIO) -> Aggregate:
+        ...
+
+    @abc.abstractmethod
+    def display(self, aggregates: Mapping[str, Aggregate]):
         ...
